@@ -27,7 +27,7 @@ from monty.io import reverse_readline, zopen
 from monty.os.path import zpath
 from six import add_metaclass
 
-from fireworks.fw_config import TRACKER_LINES, NEGATIVE_FWID_CTR
+from fireworks.fw_config import TRACKER_LINES, NEGATIVE_FWID_CTR, EXCEPT_DETAILS_ON_RERUN
 from fireworks.core.fworker import FWorker
 from fireworks.utilities.dict_mods import apply_mod
 from fireworks.utilities.fw_serializers import FWSerializable, \
@@ -278,6 +278,15 @@ class Firework(FWSerializable):
         after calling this method.
 
         """
+        if self.state == 'FIZZLED':
+            last_launch = self.launches[-1]
+            if (EXCEPT_DETAILS_ON_RERUN and last_launch.action and
+                last_launch.action.stored_data.get('_exception', {}).get('_details')):
+                # add the exception details to the spec
+                self.spec['_exception_details'] = last_launch.action.stored_data['_exception']['_details']
+            else:
+                # clean spec from stale details
+                self.spec.pop('_exception_details', None)
 
         self.archived_launches.extend(self.launches)
         self.archived_launches = list(set(self.archived_launches))  # filter duplicates
