@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 from fireworks.utilities.fw_serializers import FWSerializable, recursive_serialize, serialize_fw, \
     recursive_deserialize
 
@@ -18,7 +22,7 @@ class BackgroundTask(FWSerializable, object):
         :param tasks: [FireTask] - a list of FireTasks to perform
         :param num_launches: (int) the total number of times to run the process (0=infinite)
         :param sleep_time: (int) sleep time in seconds between background runs
-        :param run_on_finish (bool): always run this task upon completion of FireWork
+        :param run_on_finish (bool): always run this task upon completion of Firework
         """
         self.tasks = tasks if isinstance(tasks, (list, tuple)) else [tasks]
         self.num_launches = num_launches
@@ -35,4 +39,4 @@ class BackgroundTask(FWSerializable, object):
     @recursive_deserialize
     def from_dict(cls, m_dict):
         return BackgroundTask(m_dict['tasks'], m_dict['num_launches'], m_dict['sleep_time'],
-                              m_dict['run_on_finish'])
\ No newline at end of file
+                              m_dict['run_on_finish'])
