@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 from fireworks.features.dupefinder import DupeFinderBase
 
 __author__ = 'Anubhav Jain'
@@ -24,4 +28,4 @@ class DupeFinderExact(DupeFinderBase):
 
     def query(self, spec):
         return {}
-        # return {'spec': {'$elemMatch': spec}}
\ No newline at end of file
+        # return {'spec': {'$elemMatch': spec}}
