@@ -1,3 +1,7 @@
+# coding: utf-8
+
+from __future__ import unicode_literals
+
 import datetime
 from fireworks.utilities.fw_serializers import FWSerializable, serialize_fw
 
@@ -45,4 +49,4 @@ class ExportTestSerializer(FWSerializable):
 
     @classmethod
     def from_dict(cls, m_dict):
-        return ExportTestSerializer(m_dict["a"])
\ No newline at end of file
+        return ExportTestSerializer(m_dict["a"])
